@@ -13,6 +13,7 @@ from datetime import datetime
 import hashlib
 import time
 
+from jinja2.exceptions import TemplateNotFound
 from shake import url_for, from36, to36, redirect, Rule, StorageDict
 
 try:
@@ -22,7 +23,7 @@ except ImportError:
 
 from .perms import REDIRECT_FIELD_NAME, is_valid
 from .utils import (bcrypt, LazyUser, Token,
-    auth_loader, split_hash, hash_sha256, hash_sha512, hash_bcrypt)
+    auth_render, split_hash, hash_sha256, hash_sha512, hash_bcrypt)
 
 
 class UserExistsError(Exception):
@@ -197,9 +198,9 @@ class Auth(object):
 
     LazyUser = LazyUser
     
-    def __init__(self, settings, db, User, app=None):
-        self.db = db
+    def __init__(self, User, app=None, **settings):
         self.User = User
+        self.db = User.db
         
         settings = StorageDict(settings)
         for k, default in self.defaults.items():
@@ -473,6 +474,18 @@ class Auth(object):
         self.db.commit()
         return user
     
+    def render(self, view, **context):
+        try:
+            return self.settings.render(view, context)
+        except TemplateNotFound:
+            return auth_render(view, context)
+    
+    def render_to_string(self, view, **context):
+        try:
+            return self.settings.render.to_string(view, context)
+        except TemplateNotFound:
+            return auth_render.to_string(view, context)
+    
     def sign_in_view(self, request, **kwargs):
         """Signs a user in. """
         redirect_to = request.session.get(REDIRECT_FIELD_NAME)
@@ -500,9 +513,8 @@ class Auth(object):
                 return redirect(redirect_to)
             kwargs['error'] = 'FAIL'
         
-        render = self.settings.render
         view = self.settings.sign_in_view
-        return render(view, alt_loader=auth_loader, **kwargs)
+        return self.render(view, **kwargs)
     
     def sign_out_view(self, request, **kwargs):
         """Signs out a user.
@@ -520,8 +532,7 @@ class Auth(object):
         view = self.settings.sign_out_view
         if view:
             kwargs['auth'] = self
-            render = self.settings.render
-            return render(view, alt_loader=auth_loader, **kwargs)
+            return self.render(view, **kwargs)
         return redirect(redirect_to)
     
     def reset_password_view(self, request, token=None, **kwargs):
@@ -566,15 +577,12 @@ class Auth(object):
                 self.email_token(user, token)
                 kwargs['ok'] = True
         
-        render = self.settings.render
         view = self.settings.reset_password_view
-        return render(view, alt_loader=auth_loader, **kwargs)
+        return self.render(view, **kwargs)
     
     def email_token(self, user, token):
-        render = self.settings.render
         view = self.settings.email_reset_view
-        msg = render.to_string(view, {'user': user, 'token': token},
-            alt_loader=auth_loader)
+        self.render_to_string(view, {'user': user, 'token': token})
         msg = msg.encode('utf-8')
         
         mailer = self.settings.mailer
@@ -633,6 +641,5 @@ class Auth(object):
                 self.sign_in(request, user)
                 kwargs['ok'] = True
         
-        render = self.settings.render
         view = self.settings.change_password_view
-        return render(view, alt_loader=auth_loader, **kwargs)
+        return self.render(view, **kwargs)
