@@ -93,6 +93,8 @@
     MIT License. (http://www.opensource.org/licenses/mit-license.php)
 
 """
+from functools import update_wrapper
+
 from shake import redirect, NotAllowed, url_for, get_csrf_secret
 
 
@@ -165,7 +167,7 @@ def protected(perm=None, group=None, test=None, sign_in_url=None, csrf=True):
                 raise NotAllowed()
             
             return target(request, **kwargs)
-        return wrapped
+        return update_wrapper(wrapped, target)
     return real_decorator
 
 
